? my ($app, $results) = @_;
<ul id="logresults">
? for my $result (@$results) {
<li onclick="expandRange('<?= $result->[1] ?>', <?= $result->[4] ?>, this)">
? my @date = localtime($result->[0]);
? $date[5] = $date[5] % 100;
? $date[4] = $date[4] + 1;
  <div class="focus">
    <strong><?= $result->[1] ?> </strong><?= $result->[3] ?>
    <br/><span class="metadata">
      <?= $result->[2] ?>
      <?= sprintf("%02d:%02d %02d-%02d-%02d", @date[2,1,4,3,5]) ?>
    </span>
  </div>
</li>
? }
</ul>
