div.left{width:40px;}div.msg{margin-left:52px;}html,body{height:417px;}div#container{height:417px;position:relative;clear:both;}ul#tabs{display:none;}ul#controls{position:absolute;bottom:1px;left:0;right:auto;padding:0;background:#eee;}ul#controls li:hover{background:#eee;}div.window{height:417px;position:relative;}ul.messages{height:300px;overflow:auto;}div.topic{height:1.2em;overflow:hidden;}tr.input textarea{padding:3px 0 0 0;width:188px;margin-left:75px;}tr.input input.send{display:block;position:absolute;bottom:1px;right:0;}ul.messages{padding-bottom:70px;}li#config_button{display:none;}div.msg.monospace,div.msg.announce{line-height:11px;}ul.messages li{background:#fff;}ul.messages li.self{background:#fffbd0;}#tab_overflow_button img{display:none;}select.select_overlay{display:block;position:absolute;width:70px;top:1px;left:1px;bottom:auto;right:auto;border:inherit;padding:auto;margin:auto;opacity:1;font-size:12px;}ul.messages li hr{position:absolute;bottom:0;left:0;right:0;border:none;height:0;border-top:1px solid #efefef;margin:0;padding:0;}