? my ($app, @windows) = @_;

        <script type="text/javascript" src="<?= $app->static_url("alice.js") ?>?mtime=1272819991"></script>
        <script type="text/javascript" src="<?= $app->static_url("site.js") ?>?images=<?= $_[0]->config->images || 'show' ?>&amp;mtime=1272819991"></script>
        <script type="text/javascript">
          document.observe("dom:loaded", function () {
            alice.connection.msgid = <?= $_[0]->msgid ?>;
            <? for my $window (@windows) { ?>
              alice.openWindow(
                '<?= $window->id ?>',
                '<?= $window->title ?>',
                <?= $window->{active} ? "true" : "false" ?>,
                '<?= $window->hashtag ?>'
              );
            <? } ?>
            alice.focusHash();
          });
        </script>
      </div>
    </div>
    <?= $_mt->render_file('help.html', $_[0]) ?>
  </body>
</html>
