? my ($app, $window) = @_;
<div class="window<?= $window->{active} ? " active" : "" ?>" id="<?= $window->id ?>">
  <table cellspacing="0" cellpadding="0">
    <tr class="topic">
      <td>
        <div class="topic" id="<?= $window->id ?>_topic"><?= $window->topic->{string} ?></div>
      </td>
    </tr>
    <tr>
      <td valign="top">
        <div class="message_wrap">
        <ul class="messages" id="<?= $window->id ?>_messages">
        </ul>
        </div>
      </td>
    </tr>
    <tr class="input">
      <td id="<?= $window->id ?>_input">
        <div>
        <form id="<?= $window->id ?>_form" autocomplete="off">
          <input type="hidden" name="source" value="<?= $window->id ?>" />
          <input type="submit" class="send" id="<?= $window->id ?>_submit" value="Send">
          <textarea name="msg" id="<?= $window->id ?>_msg" rows="1"></textarea>
        </form>
      </div>
      </td>
    </tr>
  </table>
</div>
