? my ($app, $window, $selected) = @_;
<option value="<?= $window->id ?>" id="<?= $window->id ?>_tab_overflow_button"<? if ($window->{active}) { ?>selected="selected"<?}?>><?= $window->title ?></option>